<?php

/**
 * @file
 *
 * Files need to be imported first, because some other entities depends on
 * existance of files. For example imported "media" will generate new thumbnail
 * files if it won't find existing ones, and we will end up with duplicates.
 */

namespace Drupal\content_snapshot\EventSubscriber;

use Drupal\content_snapshot\Event\SnapshotItemEvent;
use Drupal\content_snapshot\Logger\LoggerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class NonUuidExcluderEventSubscriber.
 */
class NonUuidExcluderEventSubscriber implements EventSubscriberInterface {

  /**
   * @var \Drupal\content_snapshot\Logger\LoggerInterface
   */
  private $logger;

  public static function getSubscribedEvents() {
    return [
      SnapshotItemEvent::IMPORT_POST_CONVERTING => 'excludeNonUuid',
      SnapshotItemEvent::EXPORT_POST_CONVERTING => 'excludeNonUuid',
    ];
  }

  public function __construct(LoggerInterface $logger) {
    $this->logger = $logger;
  }

  public function excludeNonUuid(SnapshotItemEvent $contentSnapshotEvent) {
    $snapshotItem = $contentSnapshotEvent->getSnapshotItem();

    if ($snapshotItem->hasUuid()) {
      return;
    }

    $snapshotItem->setExcluded(TRUE);

    $this->logger->debug(sprintf("Item '%s' couldn't be processed because it doesn't have uuid.", $snapshotItem->getHumanifiedId()));
  }

}
